==> digikam-0.3.0.tar.gz: digikam-0.3/digikam/camera_folder.h <==
/***************************************************************************
                          camera_folder.h  -  description
                             -------------------
    begin                : Thu Dec 31 12:00:20 CST 2001
    copyright            : (C) 2001 by Renchi Raju
    email                : renchi@green.tam.uiuc.edu
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAMERA_FOLDER_H
#define CAMERA_FOLDER_H

#include <qstring.h>

#include <klistview.h>
#include <kiconview.h>


class Camera_Folder: public KListViewItem  {

 public:
  
  Camera_Folder(KListView* parent, QString folderPath, QString name);
  Camera_Folder(KListViewItem* parent, QString folderPath, QString name);
  ~Camera_Folder();
  
  void setNumSubFolders(int count);
  int  getNumSubFolders();

  void setNumImages(int count);
  int  getNumImages();

  QString getPath();
  void setName(int count);
  QString getName();

  void setOpen(bool flag);

  KIconView* iconView;

 private:
  
  int numSubFolders;
  int numImages;  
  QString path;
  QString folderName;
  
};

#endif

==> digikam-0.4.1.tar.gz: digikam-0.4.1/digikam/camera_folder.h <==
/***************************************************************************
                          camera_folder.h  -  description
                             -------------------
    begin                : Thu Dec 31 12:00:20 CST 2001
    copyright            : (C) 2001 by Renchi Raju
    email                : renchi@green.tam.uiuc.edu
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAMERA_FOLDER_H
#define CAMERA_FOLDER_H

class KListView;
class QString;
class Camera_IconView;


class Camera_Folder: public KListViewItem  {

 public:
  
  Camera_Folder(KListView* parent, QString folderPath, QString name);
  Camera_Folder(KListViewItem* parent, QString folderPath, QString name);
  ~Camera_Folder();
  
  void setNumSubFolders(int count);
  int  getNumSubFolders();

  void setNumImages(int count);
  int  getNumImages();

  QString getPath();
  void setCount(int count);
  QString getName();

  void setOpen(bool flag);

  Camera_IconView* iconView;

 private:
  
  int numSubFolders;
  int numImages;  
  QString path;
  QString folderName;
  
};

#endif
